@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# (c) Copyright 2003-2007 Hewlett-Packard Development Company, L.P.
+# (c) Copyright 2003-2015 HP Development Company, L.P.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 #
-# Author: Don Welch
+# Author: Don Welch, Naga Samrat Chowdary Narla, Yashwant Kumar Sahu, Sanjay Kumar
 #
 
 # string_table := { 'string_id' : 'short', 'long' ), ... }
@@ -34,9 +34,24 @@ class StringTable:
             'unknown' : (self.__tr('Unknown'), ''),
             'try_again' : ('', self.__tr('Please correct the problem and try again')),
             'press_continue' : ('',self.__tr('Please correct the problem and press continue on the printer')),
+            'unable_validate' : (self.__tr('Unable to validate'), ''),
+            '101' : (self.__tr('<STR1> file not found'), ''),
+            '102' : (self.__tr('<STR1> directory not found'), ''),
+            '103' : (self.__tr('Unable to connect to network. Please check your network connection and try again'), ''),
+            '104' : (self.__tr('<STR1> file does not match its checksum. File may have been corrupted or altered'), ''),
+            '105' : (self.__tr('GPG command not found'), ''),
+            '106' : (self.__tr('Unable to recieve key from keyserver'), ''),
+            '107' : (self.__tr('Failed to download <STR1>'), ''),
+            '108' : (self.__tr('Digital signature verification failed for the file <STR1>. File may have been corrupted or altered'), ''),
+            '109' : (self.__tr('Incorrect password'), ''),
+            '110' : (self.__tr('Unknown error'), ''),
+            '111' : (self.__tr('No device found having smart install enabled'), ''),
+            '112' : (self.__tr('Failed to disable smart install'), ''),
+
             '500' : (self.__tr('Started a print job'), ''),
             '501' : (self.__tr('Print job has completed'), ''),
-            '502' : (self.__tr("Print job failed - required plug-in not found"), self.__tr("Please run hp-plugin (as root) to install the required plug-in")),
+            '502' : (self.__tr("Print job failed - required plug-in not found"), self.__tr("Please run hp-plugin to install the required plug-in")),
+            '503' : (self.__tr('should not be run as root/superuser'), ''),
             '600' : (self.__tr('Started a fax job'), ''),
             '601' : (self.__tr('Fax job is ready for send'), ''),
             '700' : (self.__tr('Printer queue stopped'), ''),
@@ -99,6 +114,30 @@ class StringTable:
             '1046' : (self.__tr('In power save mode'), ''),
             '1047' : (self.__tr('Incorrect cartridge'), ''),
             '1048' : (self.__tr('Missing cartridge'), ''),
+            '1049' : (self.__tr('Missing Printhead(s)'), ''),
+
+            #Alert messages for Pentane products RQ 8888
+            '1050' : (self.__tr('ADF can not load original, please try reloading'), ''),
+            '1051' : (self.__tr('Paper too short to auto duplex'), ''),
+            '1052' : (self.__tr('Tray 2/3 missing or door open'), ''),
+            '1053' : (self.__tr('Ink too low to complete startup process'), ''),
+            '1054' : (self.__tr('Very low on ink'), ''),
+            '1055' : (self.__tr('Service ink container in duplex module in filled almost to its capacity'), self.__tr('Consider replacing duplex module from HP')),
+            '1056' : (self.__tr('Service ink container in duplex module in filled very close to its capacity'), self.__tr('Consider replacing duplex module from HP')),
+            '1057' : (self.__tr('Service ink container in duplex module is full'), self.__tr('Consider replacing duplex module from HP')),
+            '1058' : (self.__tr('Duplex module missing'), ''),
+            '1059' : (self.__tr('Printhead jam'), ''),
+            '1060' : (self.__tr('Remove paper and other material from output flap area'), ''),
+            '1061' : (self.__tr('To Maintain print quality, remove and re-install duplex module'), ''),
+            '1062' : (self.__tr('Manually feed correct paper in MP tray'), ''),
+            '1063' : (self.__tr('Printhead(s) Failed'), ''),
+            '1064' : (self.__tr('Incompatible Printhead(s)'), ''),
+            '1065' : (self.__tr('Unknown status'), ''),
+            '1066' : (self.__tr('Unable to process jobs. Please resolve printer error and then try again'), ''),
+            '1067' : (self.__tr('Printer paused'), ''),
+            '1068' : (self.__tr('Input tray is missing'), ''),
+
+
             '1501' : (self.__tr('Black cartridge is low on ink'), ''),
             '1502' : (self.__tr('Tri-color cartridge is low on ink'), ''),
             '1503' : (self.__tr('Photo cartridge is low on ink'), ''),
@@ -122,6 +161,8 @@ class StringTable:
             '1805' : (self.__tr('No toner'), '%try_again%'),
             '1806' : (self.__tr('Service request'), '%try_again%'),
             '1807' : (self.__tr('Fuser error'), '%try_again%'),
+            '1808' : (self.__tr('Empty toner'), ''),
+            '1809' : (self.__tr('Missing/Empty or incompatible toner'), ''),
             '1900' : (self.__tr('Unsupported printer model'), ''),
             '2000' : (self.__tr('Scan job started'), ''),
             '2001' : (self.__tr('Scan job completed'), ''),
@@ -133,6 +174,10 @@ class StringTable:
             '2007' : (self.__tr('Scanner automatic document feeder jam'), ''),
             '2008' : (self.__tr('Scanner automatic document feeder door opened'), ''),
             '2009' : (self.__tr('Scan job cancelled'), ''),
+            '2010' : (self.__tr('Check scan image size requirements'), ''),
+            '2011' : (self.__tr('Scanner ADF empty'), ''),
+            '2012' : (self.__tr('Scanner ADF mispick'), ''),
+            '2013' : (self.__tr('Scanner busy'), ''),
             '3000' : (self.__tr('Fax job started'), ''),
             '3001' : (self.__tr('Fax job complete'), ''),
             '3002' : (self.__tr('Fax job failed'), '%try_again%'),
@@ -161,6 +206,8 @@ class StringTable:
             '6002' : (self.__tr('Photocard unload failed'), self.__tr('Make sure photocard is inserted properly and try again')),
             '6003' : (self.__tr('Unable to mount photocard on device'), '%6002%'),
             '6004' : (self.__tr('Photocard unloaded successfully'), ''),
+            '9000' : (self.__tr('Device Added'), ''),
+            '9041' : (self.__tr('Device Removed'), ''),
             'unknown_error' : (self.__tr('Unknown error'), ''),
             'print' : (self.__tr('Print'), ''),
             'scan' : (self.__tr('Scan'), ''),
@@ -185,12 +232,33 @@ class StringTable:
             'agent_cyan_head' : (self.__tr('Cyan print head'), ''),
             'agent_cyan_supply' : (self.__tr('Cyan ink cartridge'), ''),
             'agent_cyan_cartridge' : (self.__tr('Cyan cartridge'), ''),
+            'agent_light_cyan_head' : (self.__tr('Light Cyan print head'), ''),
+            'agent_light_cyan_supply' : (self.__tr('Light Cyan ink cartridge'), ''),
+            'agent_light_cyan_cartridge' : (self.__tr('Light Cyan cartridge'), ''),
             'agent_magenta_head' : (self.__tr('Magenta print head'), ''),
             'agent_magenta_supply' : (self.__tr('Magenta ink cartridge'), ''),
             'agent_magenta_cartridge':(self.__tr('Magenta cartridge'), ''),
             'agent_yellow_head' : (self.__tr('Yellow print head'), ''),
             'agent_yellow_supply' : (self.__tr('Yellow ink cartridge'), ''),
             'agent_yellow_cartridge': (self.__tr('Yellow cartridge'), ''),
+            'agent_red_head' : (self.__tr('Red print head'), ''),
+            'agent_red_supply' : (self.__tr('Red ink cartridge'), ''),
+            'agent_red_cartridge': (self.__tr('Red cartridge'), ''),
+            'agent_photo_black_head' : (self.__tr('Photo Black print head'), ''),
+            'agent_photo_black_supply' : (self.__tr('Photo Black ink cartridge'), ''),
+            'agent_photo_black_cartridge': (self.__tr('Photo Black cartridge'), ''),
+            'agent_matte_black_head' : (self.__tr('Matte Black print head'), ''),
+            'agent_matte_black_supply' : (self.__tr('Matte Black ink cartridge'), ''),
+            'agent_matte_black_cartridge': (self.__tr('Matte Black cartridge'), ''),
+            'agent_gray_head' : (self.__tr('Gray print head'), ''),
+            'agent_gray_supply' : (self.__tr('Gray ink cartridge'), ''),
+            'agent_gray_cartridge': (self.__tr('Gray cartridge'), ''),
+            'agent_light_gray_head' : (self.__tr('Light Gray print head'), ''),
+            'agent_light_gray_supply' : (self.__tr('Light Gray ink cartridge'), ''),
+            'agent_light_gray_cartridge': (self.__tr('Light Gray cartridge'), ''),
+            'agent_dark_gray_head' : (self.__tr('Dark Gray print head'), ''),
+            'agent_dark_gray_supply' : (self.__tr('Dark Gray ink cartridge'), ''),
+            'agent_dark_gray_cartridge': (self.__tr('Dark Gray cartridge'), ''),
             'agent_photo_cyan_head' : (self.__tr('Photo cyan print head'), ''),
             'agent_photo_cyan_supply' : (self.__tr('Photo cyan ink cartridge'), ''),
             'agent_photo_cyan_cartridge' : (self.__tr('Photo cyan cartridge'), ''),
@@ -268,3 +336,81 @@ class StringTable:
 
     def __tr(self,s,c = None):
         return s
+
+import re
+from . import logger
+log = logger.Logger('', logger.Logger.LOG_LEVEL_INFO, logger.Logger.LOG_TO_CONSOLE)
+
+inter_pat = re.compile(r"""%(.*)%""", re.IGNORECASE)
+st = StringTable()
+strings_init = False
+
+
+def initStrings():
+    global strings_init, st
+    strings_init = True
+    cycles = 0
+
+    while True:
+        found = False
+
+        for s in st.string_table:
+            short_string, long_string = st.string_table[s]
+            short_replace, long_replace = short_string, long_string
+
+            try:
+                short_match = inter_pat.match(short_string).group(1)
+            except (AttributeError, TypeError):
+                short_match = None
+
+            if short_match is not None:
+                found = True
+
+                try:
+                    short_replace, dummy = st.string_table[short_match]
+                except KeyError:
+                    log.error("String interpolation error: %s" % short_match)
+
+            try:
+                long_match = inter_pat.match(long_string).group(1)
+            except (AttributeError, TypeError):
+                long_match = None
+
+            if long_match is not None:
+                found = True
+
+                try:
+                    dummy, long_replace = st.string_table[long_match]
+                except KeyError:
+                    log.error("String interpolation error: %s" % long_match)
+
+            if found:
+                st.string_table[s] = (short_replace, long_replace)
+
+        if not found:
+            break
+        else:
+            cycles +=1
+            if cycles > 1000:
+                break
+
+
+def queryString(string_id, typ=0, str1=None, str2=None):
+    if not strings_init:
+        initStrings()
+
+    s = st.string_table.get(str(string_id), ('', ''))[typ]
+   
+    if str1 is not None:
+         s = s.replace("<STR1>", str1)
+    elif "<STR" in s:
+         raise Exception("Substitution string needed for this string. <STRING: %s>" %s) 
+
+    if str2 is not None:
+         s = s.replace("<STR2>", str2)
+
+    if type(s) == type(''):
+        return s
+
+    return s()
+
