@@ -1,4 +1,4 @@
-#!/usr/local/bin/python3.12
+#!/usr/local/bin/python3.13
 # -*- coding: utf-8 -*-
 #
 # (c) Copyright 2001-2018 HP Development Company, L.P.
@@ -505,7 +505,7 @@ def sort_dict_by_value(d):
 
 
 def commafy(val):
-    return locale.format("%s", val, grouping=True)
+    return locale.format_string("%s", val, grouping=True)
 
 
 def format_bytes(s, show_bytes=False):
@@ -617,7 +617,7 @@ class UserSettings(object): # Note: Deprecated after 2.8.8 in Qt4 (see ui4/ui_ut
         if len(path):
             self.cmd_pcard = 'hp-unload -d %DEVICE_URI%'
         else:
-            self.cmd_pcard = '/usr/local/bin/python3.12 %HOME%/unload.py -d %DEVICE_URI%'
+            self.cmd_pcard = '/usr/local/bin/python3.13 %HOME%/unload.py -d %DEVICE_URI%'
 
         # Copy
         path = which('hp-makecopies')
@@ -625,7 +625,7 @@ class UserSettings(object): # Note: Deprecated after 2.8.8 in Qt4 (see ui4/ui_ut
         if len(path):
             self.cmd_copy = 'hp-makecopies -d %DEVICE_URI%'
         else:
-            self.cmd_copy = '/usr/local/bin/python3.12 %HOME%/makecopies.py -d %DEVICE_URI%'
+            self.cmd_copy = '/usr/local/bin/python3.13 %HOME%/makecopies.py -d %DEVICE_URI%'
 
         # Fax
         path = which('hp-sendfax')
@@ -633,7 +633,7 @@ class UserSettings(object): # Note: Deprecated after 2.8.8 in Qt4 (see ui4/ui_ut
         if len(path):
             self.cmd_fax = 'hp-sendfax -d %FAX_URI%'
         else:
-            self.cmd_fax = '/usr/local/bin/python3.12 %HOME%/sendfax.py -d %FAX_URI%'
+            self.cmd_fax = '/usr/local/bin/python3.13 %HOME%/sendfax.py -d %FAX_URI%'
 
         # Fax Address Book
         path = which('hp-fab')
@@ -641,7 +641,7 @@ class UserSettings(object): # Note: Deprecated after 2.8.8 in Qt4 (see ui4/ui_ut
         if len(path):
             self.cmd_fab = 'hp-fab'
         else:
-            self.cmd_fab = '/usr/local/bin/python3.12 %HOME%/fab.py'
+            self.cmd_fab = '/usr/local/bin/python3.13 %HOME%/fab.py'
 
     def load(self):
         self.loadDefaults()
@@ -2674,4 +2674,4 @@ def sanitize_filename(filename):
     # Ensure the filename only contains safe characters
     if not re.match(r'^[\w\-. ]+$', filename):
         raise ValueError("Invalid filename")
-    return filename
\ No newline at end of file
+    return filename
